@@ -7,14 +7,16 @@ from decimal import Decimal, ROUND_HALF_EVEN, localcontext
 from sql import Window
 from sql.functions import NthValue
 
+from trytond.i18n import gettext
 from trytond.model import (
     ModelView, ModelSQL, DeactivableMixin, fields, Unique, Check)
-from trytond.tools import datetime_strftime
 from trytond.transaction import Transaction
 from trytond.pool import Pool
 from trytond.rpc import RPC
 from trytond.pyson import Eval
 
+from .exceptions import RateError
+
 __all__ = ['Currency', 'Rate']
 
 
@@ -43,10 +45,6 @@ class Currency(DeactivableMixin, ModelSQL, ModelView):
     def __setup__(cls):
         super(Currency, cls).__setup__()
         cls._order.insert(0, ('code', 'ASC'))
-        cls._error_messages.update({
-                'no_rate': ('No rate found for currency "%(currency)s" on '
-                    '"%(date)s"'),
-                })
         cls.__rpc__.update({
                 'compute': RPC(instantiate=slice(0, 3, 2)),
                 })
@@ -136,8 +134,6 @@ class Currency(DeactivableMixin, ModelSQL, ModelView):
 
     def round(self, amount, rounding=ROUND_HALF_EVEN):
         'Round the amount depending of the currency'
-        if not self.rounding:
-            return amount
         with localcontext() as ctx:
             ctx.prec = max(ctx.prec, (amount / self.rounding).adjusted() + 1)
             # Divide and multiple by rounding for case rounding is not 10En
@@ -147,9 +143,7 @@ class Currency(DeactivableMixin, ModelSQL, ModelView):
 
     def is_zero(self, amount):
         'Return True if the amount can be considered as zero for the currency'
-        if not self.rounding:
-            return not amount
-        return abs(self.round(amount)) < abs(self.rounding)
+        return abs(self.round(amount)) < self.rounding
 
     @classmethod
     def compute(cls, from_currency, amount, to_currency, round=True):
@@ -175,13 +169,10 @@ class Currency(DeactivableMixin, ModelSQL, ModelView):
             else:
                 name = to_currency.name
 
-            languages = Lang.search([
-                    ('code', '=', Transaction().language),
-                    ])
-            cls.raise_user_error('no_rate', {
-                    'currency': name,
-                    'date': datetime_strftime(date, str(languages[0].date))
-                    })
+            lang = Lang.get()
+            raise RateError(gettext('currency.msg_no_rate',
+                    currency=name,
+                    date=lang.strftime(date)))
         if round:
             return to_currency.round(
                 amount * to_currency.rate / from_currency.rate)
@@ -240,9 +231,9 @@ class Rate(ModelSQL, ModelView):
         t = cls.__table__()
         cls._sql_constraints = [
             ('date_currency_uniq', Unique(t, t.date, t.currency),
-                'A currency can only have one rate by date.'),
+                'currency.msg_currency_unique_rate_date'),
             ('check_currency_rate', Check(t, t.rate >= 0),
-                'The currency rate must greater than or equal to 0'),
+                'currency.msg_currency_rate_positive'),
             ]
         cls._order.insert(0, ('date', 'DESC'))
 
